@@ -1,8 +1,8 @@
-/*  $Id: GameEngine.cpp,v 1.13 2010/05/02 02:30:14 sarrazip Exp $
+/*  $Id: GameEngine.cpp,v 1.15 2010/08/15 02:16:11 sarrazip Exp $
     GameEngine.cpp - Abstract class representing an SDL Game Engine.
 
     flatzebra - Generic 2D Game Engine library
-    Copyright (C) 1999-2010 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 1999-2012 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include <flatzebra/GameEngine.h>
@@ -92,6 +92,7 @@ GameEngine::GameEngine(Couple screenSizeInPixels,
 GameEngine::~GameEngine()
 {
     SDL_FreeSurface(fixedWidthFontPixmap);
+    SDL_FreeSurface(theSDLScreen);
     SDL_Quit();
 }
 
