@@ -1,8 +1,8 @@
-/*  $Id: PixmapArray.cpp,v 1.2 2010/04/25 01:15:57 sarrazip Exp $
+/*  $Id: PixmapArray.cpp,v 1.4 2012/03/28 02:55:45 sarrazip Exp $
     PixmapArray.cpp - Object containing an array of Pixmaps.
 
     flatzebra - Generic 2D Game Engine library
-    Copyright (C) 1999, 2000, 2001 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 1999-2012 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include <flatzebra/PixmapArray.h>
@@ -28,28 +28,39 @@ using namespace std;
 using namespace flatzebra;
 
 
-PixmapArray::PixmapArray(size_t numImages)
-  : images(numImages, NULL),
+PixmapArray::PixmapArray(size_t)
+  : images(),
     imageSize(0, 0)
 {
-    assert(numImages > 0);
 }
 
 
 PixmapArray::~PixmapArray()
+{
+    freeImages();
+}
+
+
+void
+PixmapArray::freeImages()
 {
     for (vector<SDL_Surface *>::iterator it = images.begin();
                                         it != images.end(); it++)
         SDL_FreeSurface(*it);
+
+    images.clear();
 }
 
 
 void
 PixmapArray::setArrayElement(size_t i, SDL_Surface *image)
 {
-    assert(i < images.size());
+    assert(i < 10000);  // sanity check
     assert(image != NULL);
 
+    if (i >= images.size())
+        images.resize(i + 1, NULL);
+
     images[i] = image;
 }
 
