@@ -1,4 +1,4 @@
-/*  $Id: RSprite.cpp,v 1.3 2010/05/16 01:50:19 sarrazip Exp $
+/*  $Id: RSprite.cpp,v 1.5 2010/07/31 05:29:45 sarrazip Exp $
     RSprite.cpp - Sprite with floating point coordinates in a 2D game.
 
     flatzebra - Generic 2D Game Engine library
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include <flatzebra/RSprite.h>
@@ -81,16 +81,7 @@ bool RSprite::collidesWithRSprite(const RSprite &s) const
     const RCouple &pos2  = s2.getPos() + s2.collBoxPos;
     const RCouple &size2 = s2.collBoxSize;
 
-    if (pos1.x + size1.x <= pos2.x)  // s1 at the left of s2
-        return false;
-    if (pos1.y + size1.y <= pos2.y)  // s1 above s2
-        return false;
-    if (pos2.x + size2.x <= pos1.x)  // s1 at the right of s2
-        return false;
-    if (pos2.y + size2.y <= pos1.y)  // s1 below s2
-        return false;
-
-    return true;
+    return RCouple::rectangleCollision(pos1, size1, pos2, size2);
 }
 
 
