@@ -1,4 +1,4 @@
-/*  $Id: SoundMixer.cpp,v 1.4 2010/05/16 01:50:19 sarrazip Exp $
+/*  $Id: SoundMixer.cpp,v 1.7 2010/12/31 02:20:44 sarrazip Exp $
     SoundMixer.cpp - Sound mixer based on the SDL_mixer library
 
     flatzebra - Generic 2D Game Engine library
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include "SoundMixer.h"
@@ -28,7 +28,13 @@ using namespace flatzebra;
 
 SoundMixer::SoundMixer(int numChannels) throw(Error)
 {
-    if (Mix_OpenAudio(11025, AUDIO_U8, 1, 128) == -1)
+    int chunksize;
+    #ifdef _MSC_VER
+    chunksize = 512;
+    #else
+    chunksize = 128;
+    #endif
+    if (Mix_OpenAudio(11025, AUDIO_U8, 1, chunksize) == -1)
         throw Error("SoundMixer(): " + string(Mix_GetError()));
 
     Mix_AllocateChannels(numChannels);
